#
# spec file for package Jamulus
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2014 Pascal Bleser <pascal.bleser@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           Jamulus
Version:        3.4.2
Release:        lp150.1.2
Summary:        Low-latency internet connection tool for real-time jam sessions
License:        GPL-2.0+
Group:          Productivity/Multimedia/Sound/Utilities
URL:            http://llcon.sourceforge.net/index.html
Source0:        https://sourceforge.net/projects/llcon/files/Jamulus/%{version}/Jamulus-%{version}.tar.gz
Source1:        %{name}.png
BuildRequires:  ImageMagick
BuildRequires:  gcc-c++
BuildRequires:  hicolor-icon-theme
BuildRequires:  jack-devel
BuildRequires:  pkgconfig
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5Widgets)
BuildRequires:  pkgconfig(Qt5Xml)
BuildRequires:  pkgconfig(opus)
Requires:       jack
Provides:       llcon = %{version}
Obsoletes:      llcon < %{version}
Provides:       jamulus = %{version}-%{release}
Obsoletes:      jamulus

%description
The Jamulus software enables musicians to perform real-time jam sessions over
the internet. There is one server running the Jamulus server software which
collects the audio data from each Jamulus client software, mixes the audio data
and sends the mix back to each client.

%prep
%setup -q -n %{name}%{version}
sed -i -e '/^Exec/cExec=%{name}' -e '/^Icon/cIcon=%{name}' src/res/jamulus.desktop
chmod -x README
install %{SOURCE1} .

%build
%qmake5 CONFIG+=opus_shared_lib
make %{?_smp_mflags}

%install
install -D -m0755 Jamulus %{buildroot}%{_bindir}/%{name}
install -D -m0644 src/res/jamulus.desktop %{buildroot}%{_datadir}/applications/%{name}.desktop
for s in 16 22 32 48 64 72 96 128 192; do
   mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps
   convert -strip -resize ${s}x${s} %{name}.png \
    %{buildroot}%{_datadir}/icons/hicolor/${s}x${s}/apps/%{name}.png
done
mkdir -p %{buildroot}%{_datadir}/pixmaps
pushd %{buildroot}%{_datadir}/pixmaps
ln -s ../icons/hicolor/48x48/apps/%{name}.png .
popd

%files
%doc README AUTHORS ChangeLog TODO
%license COPYING
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_datadir}/icons/hicolor/*/apps/%{name}.png
%{_datadir}/pixmaps/%{name}.png

%changelog
* Fri Mar 16 2018 olaf@aepfle.de
- obsolete jamulus to allow pkg migration from packman to OBS
* Fri Mar  9 2018 aloisio@gmx.com
- Update to version 3.4.2
  * removed old CELT library (minimum compatible version is now
    3.3.1)
  * show server name in the server list in bold font if it is a
    permanent server
  version  3.4.1
  * avoid a single jitter buffer for the auto detection
  * the Musicians value in the server list shows a warning if the
    server is full
  * automatic server setting for permanent server flag in the
    protocol
  * bug fix: ping time measurement may be invalid for the Linux OS
  version 3.4.0
  * show the names of the connected clients in the server list
  version 3.3.11
  * added a new client fader level setting
  version 3.3.10
  * changed the default central server URL
  * added support for server disconnection
  version 3.3.9
  * another improvement of auto jitter buffer detection in very bad
    network conditions
  * support client operation without using a GUI front end
  version 3.3.8
  * improved audio quality in bad network conditions
  * more realistic overall delay estimation
  * improvement of auto jitter buffer detection in bad network
    conditions
  * show info about sound card buffer size if not one of the
    standard sizes
  version 3.3.7
  * added a musician profile dialog (some settings in the main
    window were removed)
  * a tool tip for the fader tag shows the complete musician
    profile
  * the city and skill level can be set in the musician profile
  * added new instrument picture for "Guitar+Vocal"
  version 3.3.6
  * support for a country flag icon on the fader tag
  * a licence agreement dialog can be requested by the server
  version 3.3.5
  * new compile config options for disabling old CELT, use OPUS in
    a shared library and change the executable name
  * added a Linux jamulus.desktop file
  version 3.3.4
  * true stereo reverberation effect (previously it was a mono
    reverberation effect on both stereo channels)
  * added a mono-in/stereo-out mode to support special sound cards
    which have mono inputs for the instrument and a microphone but
    have stereo outputs
  * store fader solo state in the ini file
  * improved stability of the audio stream by reducing audio drop
    outs (by using a separate socket thread)
  * removed unnecessary settings and LED indicators
  * bug fix: the fader level could not be changed if the fader was
    on solo
- Switched to Qt5 build
- Use system libopus
- Added Jamulus.png as source (icon of adequate size)
* Fri Jan  3 2014 pascal.bleser@opensuse.org
- initial version (3.3.3)
